<?php

/**
 * Plugin main file.
 *
 * @link              https://www.symmetria.hr
 * @since             1.0.0
 * @package           Woo_KigoKasa_Api
 *
 * @wordpress-plugin
 * Plugin Name:       KigoKasa API for WooCommerce
 * Plugin URI:        https://www.symmetria.hr/kigokasa-api-for-woocommerce/
 * Description:       This plugin provides integration of KigoKasa API service with WooCommerce. Plugin integrates with WooCommerce checkout process and sends API request with the order details to the KigoKasa service.
 * Version:           1.2.5
 * Author:            Symmetria d.o.o.
 * Author URI:        https://www.symmetria.hr/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       kigokasa-api-for-woocommerce
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WOO_KIGOKASA_API_PLUGIN_NAME_VERSION', '1.2.4' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-kigokasa-api-for-woocommerce-activator.php
 */
function woo_kigokasa_api_activate_plugin_name() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-woo-kigokasa-api-activator.php';
	Woo_KigoKasa_Api_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-kigokasa-api-for-woocommerce-deactivator.php
 */
function woo_kigokasa_api_deactivate_plugin_name() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-woo-kigokasa-api-deactivator.php';
	Woo_KigoKasa_Api_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'woo_kigokasa_api_activate_plugin_name' );
register_deactivation_hook( __FILE__, 'woo_kigokasa_api_deactivate_plugin_name' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-woo-kigokasa-api.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function woo_kigokasa_api_run_plugin_name() {

	$plugin = new Woo_KigoKasa_Api();
	$plugin->run();

}
woo_kigokasa_api_run_plugin_name();
